@@ -1,4 +1,5 @@
 # sage_setup: distribution = sagemath-kenzo
+# sage.doctest: optional - kenzo
 r"""
 Library interface to Kenzo
 
@@ -1726,7 +1727,7 @@ class KenzoChainComplexMorphism(KenzoObject):
     def change_source_target_complex(self, source=None, target=None):
         r"""
         Build, from the morphism ``self``, a new morphism with ``source``
-        and ``target`` as source and target Kenzo chain complexes, respectively.
+        and ``target`` as source and target Kenzo chain complexes.
 
         INPUT:
 
@@ -1740,8 +1741,8 @@ class KenzoChainComplexMorphism(KenzoObject):
           degree (:degr slot in Kenzo), the algorithm (:intr slot in Kenzo)
           and the strategy (:strt slot in Kenzo). The source and target slots
           of this new morphism are given by the parameters ``source`` and
-          ``target`` respectively; if any parameter is ommited, the corresponding
-          slot is inherited from ``self``.
+          ``target`` respectively; if any parameter is omitted,
+          the corresponding slot is inherited from ``self``.
 
         EXAMPLES::
 
@@ -1774,8 +1775,8 @@ class KenzoChainComplexMorphism(KenzoObject):
 
     def destructive_change_source_target_complex(self, source=None, target=None):
         r"""
-        Modify destructively the morphism ``self`` taking ``source`` and ``target`` as source and
-        target Kenzo chain complexes of ``self``, respectively.
+        Modify destructively the morphism ``self`` taking ``source``
+        and ``target`` as source and target Kenzo chain complexes of ``self``.
 
         INPUT:
 
@@ -1785,9 +1786,10 @@ class KenzoChainComplexMorphism(KenzoObject):
 
         OUTPUT:
 
-        - A :class:`KenzoChainComplexMorphism`. The source and target slots of ``self`` are replaced
-          respectively by the parameters ``source`` and ``target``; if any parameter is ommited, the
-          corresponding slot is inherited from ``self``.
+        - A :class:`KenzoChainComplexMorphism`. The source and target
+          slots of ``self`` are replaced respectively by the
+          parameters ``source`` and ``target``; if any parameter is
+          omitted, the corresponding slot is inherited from ``self``.
 
         EXAMPLES::
 
